Documentation
¶
Overview ¶
Package coveragecheck evaluates coverage for changed Go source lines.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChangedLines ¶
ChangedLines maps repository-relative files to added line numbers.
type Report ¶
Report summarizes coverage for coverable changed lines.
func Evaluate ¶
func Evaluate(blocks []Block, changed ChangedLines) Report
Evaluate reports coverage for changed lines intersecting statement blocks.
func (Report) MeetsThreshold ¶
MeetsThreshold reports whether the changed-line coverage meets threshold.
Click to show internal directories.
Click to hide internal directories.